# KaneAI

A package for automation using Selenium.

## Installation

```bash
pip install kaneai
```

## Development Installation

```bash
pip install -e .
```

## Build Package

```bash
python -m build
```
The package will be created in the `dist/` folder.

## Project Links

- [GitHub Repository](https://github.com/LambdatestIncPrivate/web-kaneai-code-runner)